@@ -69,7 +69,7 @@ class FileStorageURIResolver(Resolver):
         prefix, rest = uri.split('file://', 1)
         result = rest.split('?', 1)
         if len(result) == 1:
-            path = result
+            path = result[0]
             query = ''
         else:
             path, query = result
@@ -163,13 +163,13 @@ class ClientStorageURIResolver(Resolver):
                 from ZODB.DB import DB
                 from ZODB.DemoStorage import DemoStorage
                 demostorage = DemoStorage(base=ClientStorage(*args, **kw))
-                return DB(demostorage, **dbkw)
+                return DB(demostorage, **dbkw) #pragma NO COVERAGE
         else:
             def factory():
                 from ZEO.ClientStorage import ClientStorage
                 from ZODB.DB import DB
                 clientstorage = ClientStorage(*args, **kw)
-                return DB(clientstorage, **dbkw)
+                return DB(clientstorage, **dbkw) #pragma NO COVERAGE
         return key, args, kw, factory
 
 def get_dbkw(kw):
